# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal, Required, TypedDict

__all__ = ["V1TranslateParams"]


class V1TranslateParams(TypedDict, total=False):
    content: Required[str]
    """Text to translate verbatim"""

    target_language: Required[Literal["en", "es", "fr", "de", "it"]]
    """Target language code (ISO-639-1)"""

    metadata: Dict[str, object]
    """Arbitrary metadata echoed back"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from .._models import BaseModel

__all__ = ["V1DeidentifyResponse", "Config"]


class Config(BaseModel):
    pipeline_name: Optional[str] = None
    """Name of the pipeline used for deidentification"""

    server_version: Optional[str] = None
    """Version of the Medici server"""

    transformers_model: Optional[str] = None
    """HuggingFace model path used for deidentification via transformers"""


class V1DeidentifyResponse(BaseModel):
    config: Config
    """Configuration parameters used"""

    content: str
    """Content stripped of PHI"""

    explanation: Optional[Dict[str, object]] = None
    """An explanation of the deidentification process, as a JSON object"""

    metadata: Optional[Dict[str, str]] = None
    """Additional output metadata"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from medici import Medici, AsyncMedici
from tests.utils import assert_matches_type
from medici.types import V1TranslateResponse, V1DeidentifyResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_deidentify(self, client: Medici) -> None:
        v1 = client.v1.deidentify(
            pipeline="roberta_i2b2",
            content="x",
        )
        assert_matches_type(V1DeidentifyResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_deidentify_with_all_params(self, client: Medici) -> None:
        v1 = client.v1.deidentify(
            pipeline="roberta_i2b2",
            content="x",
            config={
                "approach": "replace",
                "fixed_mrns": ["string"],
                "fixed_names": ["string"],
                "return_analysis": True,
                "return_explanation": True,
                "user_id": "user_id",
            },
            metadata={"foo": "string"},
        )
        assert_matches_type(V1DeidentifyResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_deidentify(self, client: Medici) -> None:
        response = client.v1.with_raw_response.deidentify(
            pipeline="roberta_i2b2",
            content="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1DeidentifyResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_deidentify(self, client: Medici) -> None:
        with client.v1.with_streaming_response.deidentify(
            pipeline="roberta_i2b2",
            content="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1DeidentifyResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_translate(self, client: Medici) -> None:
        v1 = client.v1.translate(
            content="content",
            target_language="en",
        )
        assert_matches_type(V1TranslateResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_translate_with_all_params(self, client: Medici) -> None:
        v1 = client.v1.translate(
            content="content",
            target_language="en",
            metadata={"foo": "bar"},
        )
        assert_matches_type(V1TranslateResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_translate(self, client: Medici) -> None:
        response = client.v1.with_raw_response.translate(
            content="content",
            target_language="en",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1TranslateResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_translate(self, client: Medici) -> None:
        with client.v1.with_streaming_response.translate(
            content="content",
            target_language="en",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1TranslateResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_deidentify(self, async_client: AsyncMedici) -> None:
        v1 = await async_client.v1.deidentify(
            pipeline="roberta_i2b2",
            content="x",
        )
        assert_matches_type(V1DeidentifyResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_deidentify_with_all_params(self, async_client: AsyncMedici) -> None:
        v1 = await async_client.v1.deidentify(
            pipeline="roberta_i2b2",
            content="x",
            config={
                "approach": "replace",
                "fixed_mrns": ["string"],
                "fixed_names": ["string"],
                "return_analysis": True,
                "return_explanation": True,
                "user_id": "user_id",
            },
            metadata={"foo": "string"},
        )
        assert_matches_type(V1DeidentifyResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_deidentify(self, async_client: AsyncMedici) -> None:
        response = await async_client.v1.with_raw_response.deidentify(
            pipeline="roberta_i2b2",
            content="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1DeidentifyResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_deidentify(self, async_client: AsyncMedici) -> None:
        async with async_client.v1.with_streaming_response.deidentify(
            pipeline="roberta_i2b2",
            content="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1DeidentifyResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_translate(self, async_client: AsyncMedici) -> None:
        v1 = await async_client.v1.translate(
            content="content",
            target_language="en",
        )
        assert_matches_type(V1TranslateResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_translate_with_all_params(self, async_client: AsyncMedici) -> None:
        v1 = await async_client.v1.translate(
            content="content",
            target_language="en",
            metadata={"foo": "bar"},
        )
        assert_matches_type(V1TranslateResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_translate(self, async_client: AsyncMedici) -> None:
        response = await async_client.v1.with_raw_response.translate(
            content="content",
            target_language="en",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1TranslateResponse, v1, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_translate(self, async_client: AsyncMedici) -> None:
        async with async_client.v1.with_streaming_response.translate(
            content="content",
            target_language="en",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1TranslateResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v1_translate_params import V1TranslateParams as V1TranslateParams
from .v1_deidentify_params import V1DeidentifyParams as V1DeidentifyParams
from .v1_translate_response import V1TranslateResponse as V1TranslateResponse
from .v1_deidentify_response import V1DeidentifyResponse as V1DeidentifyResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["V1TranslateResponse"]


class V1TranslateResponse(BaseModel):
    original_language_name: str
    """The language of the original text, as detected by the parser"""

    translated_language_name: str
    """The target language for translation, as specified in the request"""

    translated_text: str
    """The original text translated into the target language"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional
from typing_extensions import Literal, Required, TypedDict

__all__ = ["V1DeidentifyParams", "Config"]


class V1DeidentifyParams(TypedDict, total=False):
    content: Required[str]
    """Test with PHI to deidentify"""

    config: Config
    """Configuration parameters"""

    metadata: Dict[str, str]
    """Ad hoc configuration properties, eg for logging or observability"""


class Config(TypedDict, total=False):
    approach: Literal["replace", "redact"]
    """Approach to identified entities"""

    fixed_mrns: Optional[List[str]]
    """List of known MRNs as fallback for primary deidentifier"""

    fixed_names: Optional[List[str]]
    """List of known names as fallback for primary deidentifiers.

    Names are split to word and only 3+ letter words are used.
            First names are supplemented by known matching nicknames.
    """

    return_analysis: bool
    """Whether to return the analysis process"""

    return_explanation: bool
    """Whether to return an explanation of the analysis process"""

    user_id: str
    """UserID for caller"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict
from typing_extensions import Literal

import httpx

from ..types import v1_translate_params, v1_deidentify_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.v1_translate_response import V1TranslateResponse
from ..types.v1_deidentify_response import V1DeidentifyResponse

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/natecobb/medici-client#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/natecobb/medici-client#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def deidentify(
        self,
        pipeline: Literal["roberta_i2b2", "stanford_aimi"],
        *,
        content: str,
        config: v1_deidentify_params.Config | NotGiven = NOT_GIVEN,
        metadata: Dict[str, str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1DeidentifyResponse:
        """
        Deidentify

        Args:
          content: Test with PHI to deidentify

          config: Configuration parameters

          metadata: Ad hoc configuration properties, eg for logging or observability

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pipeline:
            raise ValueError(f"Expected a non-empty value for `pipeline` but received {pipeline!r}")
        return self._post(
            f"/api/v1/deidentify/{pipeline}",
            body=maybe_transform(
                {
                    "content": content,
                    "config": config,
                    "metadata": metadata,
                },
                v1_deidentify_params.V1DeidentifyParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1DeidentifyResponse,
        )

    def translate(
        self,
        *,
        content: str,
        target_language: Literal["en", "es", "fr", "de", "it"],
        metadata: Dict[str, object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1TranslateResponse:
        """
        Translate

        Args:
          content: Text to translate verbatim

          target_language: Target language code (ISO-639-1)

          metadata: Arbitrary metadata echoed back

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/api/v1/translate",
            body=maybe_transform(
                {
                    "content": content,
                    "target_language": target_language,
                    "metadata": metadata,
                },
                v1_translate_params.V1TranslateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1TranslateResponse,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/natecobb/medici-client#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/natecobb/medici-client#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def deidentify(
        self,
        pipeline: Literal["roberta_i2b2", "stanford_aimi"],
        *,
        content: str,
        config: v1_deidentify_params.Config | NotGiven = NOT_GIVEN,
        metadata: Dict[str, str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1DeidentifyResponse:
        """
        Deidentify

        Args:
          content: Test with PHI to deidentify

          config: Configuration parameters

          metadata: Ad hoc configuration properties, eg for logging or observability

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not pipeline:
            raise ValueError(f"Expected a non-empty value for `pipeline` but received {pipeline!r}")
        return await self._post(
            f"/api/v1/deidentify/{pipeline}",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "config": config,
                    "metadata": metadata,
                },
                v1_deidentify_params.V1DeidentifyParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1DeidentifyResponse,
        )

    async def translate(
        self,
        *,
        content: str,
        target_language: Literal["en", "es", "fr", "de", "it"],
        metadata: Dict[str, object] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> V1TranslateResponse:
        """
        Translate

        Args:
          content: Text to translate verbatim

          target_language: Target language code (ISO-639-1)

          metadata: Arbitrary metadata echoed back

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/api/v1/translate",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "target_language": target_language,
                    "metadata": metadata,
                },
                v1_translate_params.V1TranslateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1TranslateResponse,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.deidentify = to_raw_response_wrapper(
            v1.deidentify,
        )
        self.translate = to_raw_response_wrapper(
            v1.translate,
        )


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.deidentify = async_to_raw_response_wrapper(
            v1.deidentify,
        )
        self.translate = async_to_raw_response_wrapper(
            v1.translate,
        )


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.deidentify = to_streamed_response_wrapper(
            v1.deidentify,
        )
        self.translate = to_streamed_response_wrapper(
            v1.translate,
        )


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.deidentify = async_to_streamed_response_wrapper(
            v1.deidentify,
        )
        self.translate = async_to_streamed_response_wrapper(
            v1.translate,
        )
